<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace FiloBlu\Rma\Block\Adminhtml\Order\View;

use Magento\Framework\View\Element\Template;
use Magento\Sales\Model\OrderRepository;

/**
 * Order history block
 *
 * @api
 * @since 100.0.2
 */
class AdditionalInformations extends \Magento\Framework\View\Element\Template
{

    protected $orderRepository;

    /**
     * AdditionalInformations constructor.
     * @param Template\Context $context
     * @param OrderRepository $orderRepository
     * @param array $data
     */
    public function __construct(Template\Context $context,
                                OrderRepository $orderRepository,
                                array $data = [])
    {
        $this->orderRepository = $orderRepository;
        parent::__construct($context, $data);
    }


    /**
     * @return string
     * @throws \Magento\Framework\Exception\InputException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getPaymentAdditionalInfo()
    {
        $order_id = $this->getRequest()->getParam('order_id');
        $html  ='';
        if($order_id) {
            $order = $this->orderRepository->get($order_id);
            $paymentAdditionalInformation = $order->getPayment()->getAdditionalInformation();
            foreach ($paymentAdditionalInformation as $key => $val){
                if($key == 'parent_order'){
                    $html .="<div>Parent Order: ".$this->getOrderLink($val)."</div>";
                }elseif(is_array($val)){
                    /*
                     * Orders placed by Credit Card using 3D secure V2, returns some additional information in an array.
                     * Fix made for this case.
                     */
                    $html .="<div>$key : " . var_export($val, TRUE) . "</div>";
                }else {
                    $html .="<div>$key : $val</div>";
                }

            }
        }
        return $html;
    }

    /**
     * @param $orderId
     * @return string
     */
    public function getOrderLink($orderId)
    {
        $html = '';
        if($orderId)
        {
            $html .="<a href='";
            $html .= $this->_urlBuilder->getUrl('sales/order/view',
                [
                    'order_id' => $orderId
                ]);
            $html .="'>$orderId</a>";
        }
        return $html;
    }
}
